package com.bonus.material.purchase.mapper;

import java.util.List;
import com.bonus.material.purchase.domain.PurchasePartDetails;

/**
 * 新购配件验收任务详细Mapper接口
 * 
 * @author xsheng
 * @date 2024-10-16
 */
public interface PurchasePartDetailsMapper {
    /**
     * 查询新购配件验收任务详细
     * 
     * @param id 新购配件验收任务详细主键
     * @return 新购配件验收任务详细
     */
    public PurchasePartDetails selectPurchasePartDetailsById(Long id);

    /**
     * 查询新购配件验收任务详细列表
     * 
     * @param purchasePartDetails 新购配件验收任务详细
     * @return 新购配件验收任务详细集合
     */
    public List<PurchasePartDetails> selectPurchasePartDetailsList(PurchasePartDetails purchasePartDetails);

    /**
     * 新增新购配件验收任务详细
     * 
     * @param purchasePartDetails 新购配件验收任务详细
     * @return 结果
     */
    public int insertPurchasePartDetails(PurchasePartDetails purchasePartDetails);

    /**
     * 修改新购配件验收任务详细
     * 
     * @param purchasePartDetails 新购配件验收任务详细
     * @return 结果
     */
    public int updatePurchasePartDetails(PurchasePartDetails purchasePartDetails);

    /**
     * 删除新购配件验收任务详细
     * 
     * @param id 新购配件验收任务详细主键
     * @return 结果
     */
    public int deletePurchasePartDetailsById(Long id);

    /**
     * 批量删除新购配件验收任务详细
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePurchasePartDetailsByIds(Long[] ids);
}
