package com.bonus.material.purchase.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.purchase.domain.PurchasePartDetails;
import com.bonus.material.purchase.service.IPurchasePartDetailsService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 新购配件验收任务详细Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "新购配件验收任务详细接口")
@RestController
@RequestMapping("/purchase_part_details")
public class PurchasePartDetailsController extends BaseController {
    @Autowired
    private IPurchasePartDetailsService purchasePartDetailsService;

    /**
     * 查询新购配件验收任务详细列表
     */
    @ApiOperation(value = "查询新购配件验收任务详细列表")
    @RequiresPermissions("purchase:details:list")
    @GetMapping("/list")
    public TableDataInfo list(PurchasePartDetails purchasePartDetails) {
        startPage();
        List<PurchasePartDetails> list = purchasePartDetailsService.selectPurchasePartDetailsList(purchasePartDetails);
        return getDataTable(list);
    }

    /**
     * 导出新购配件验收任务详细列表
     */
    @ApiOperation(value = "导出新购配件验收任务详细列表")
    @PreventRepeatSubmit
    @RequiresPermissions("purchase:details:export")
    @SysLog(title = "新购配件验收任务详细", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出新购配件验收任务详细")
    @PostMapping("/export")
    public void export(HttpServletResponse response, PurchasePartDetails purchasePartDetails) {
        List<PurchasePartDetails> list = purchasePartDetailsService.selectPurchasePartDetailsList(purchasePartDetails);
        ExcelUtil<PurchasePartDetails> util = new ExcelUtil<PurchasePartDetails>(PurchasePartDetails.class);
        util.exportExcel(response, list, "新购配件验收任务详细数据");
    }

    /**
     * 获取新购配件验收任务详细详细信息
     */
    @ApiOperation(value = "获取新购配件验收任务详细详细信息")
    @RequiresPermissions("purchase:details:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(purchasePartDetailsService.selectPurchasePartDetailsById(id));
    }

    /**
     * 新增新购配件验收任务详细
     */
    @ApiOperation(value = "新增新购配件验收任务详细")
    @PreventRepeatSubmit
    @RequiresPermissions("purchase:details:add")
    @SysLog(title = "新购配件验收任务详细", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增新购配件验收任务详细")
    @PostMapping
    public AjaxResult add(@RequestBody PurchasePartDetails purchasePartDetails) {
        try {
            return toAjax(purchasePartDetailsService.insertPurchasePartDetails(purchasePartDetails));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改新购配件验收任务详细
     */
    @ApiOperation(value = "修改新购配件验收任务详细")
    @PreventRepeatSubmit
    @RequiresPermissions("purchase:details:edit")
    @SysLog(title = "新购配件验收任务详细", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改新购配件验收任务详细")
    @PutMapping
    public AjaxResult edit(@RequestBody PurchasePartDetails purchasePartDetails) {
        try {
            return toAjax(purchasePartDetailsService.updatePurchasePartDetails(purchasePartDetails));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除新购配件验收任务详细
     */
    @ApiOperation(value = "删除新购配件验收任务详细")
    @PreventRepeatSubmit
    @RequiresPermissions("purchase:details:remove")
    @SysLog(title = "新购配件验收任务详细", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除新购配件验收任务详细")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(purchasePartDetailsService.deletePurchasePartDetailsByIds(ids));
    }
}
